"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _chalk = require("chalk");

var _depcheck = _interopRequireWildcard(require("depcheck"));

var _dependencyError = _interopRequireDefault(require("../../errors/dependencyError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const ignorePackage = ['@types/node', 'typescript'];
const options = {
  ignoreDirs: ['node_modules'],
  parsers: {
    '**/*.js': _depcheck.parser.es6,
    '**/*.jsx': _depcheck.parser.jsx,
    '**/*.ts': _depcheck.parser.typescript,
    '**/*.tsx': _depcheck.parser.typescript
  },
  detectors: [_depcheck.detector.requireCallExpression, _depcheck.detector.importDeclaration],
  specials: [_depcheck.special.babel, _depcheck.special.eslint, _depcheck.special.prettier, _depcheck.special.jest, _depcheck.special.husky]
};

const depcheck = async ({
  cwd
}, ignorePackages = []) => {
  const result = await (0, _depcheck.default)(cwd, { ...options,
    ignoreMatches: [...ignorePackages, ...ignorePackage]
  });
  const groups = [{
    title: (0, _chalk.red)('The dependencies are not used'),
    dependencies: result.dependencies
  }, {
    title: (0, _chalk.yellow)('The dev-dependencies are not used'),
    dependencies: result.devDependencies
  }, {
    title: (0, _chalk.blue)('The dependencies is missing'),
    dependencies: Object.keys(result.missing)
  }];
  const output = groups.filter(({
    dependencies
  }) => dependencies.length > 0).flatMap(({
    title,
    dependencies
  }) => [`▸ ${title}`, ...dependencies.sort().map(v => `  ∙ ${v}`), '']);

  if (output.length > 0) {
    throw new _dependencyError.default('Depcheck error', output);
  }
};

var _default = depcheck;
exports.default = _default;