"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.getCoverageFolder = void 0;

var _path = require("path");

var _exec = _interopRequireDefault(require("../../cmd/exec"));

var _existFiles = _interopRequireDefault(require("../../cmd/existFiles"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const configFiles = ['jest.config.js', 'jest.config.ts'];
const options = ['updateSnapshot', 'runInBand', 'watch'];

const getCoverageFolder = (cwd, projects) => (0, _path.join)(cwd, 'coverage', projects.length === 1 ? `_${projects}` : '');

exports.getCoverageFolder = getCoverageFolder;

const jest = async ({
  cwd,
  ci,
  log
}, props) => {
  const coverageFolder = getCoverageFolder(cwd, props.projects);
  const files = await (0, _existFiles.default)(configFiles, cwd);

  if (files.length === 0) {
    throw new Error('Jest config file was not found');
  }

  const cmd = './node_modules/.bin/jest';
  const args = ['--colors', '--config', files[0]];

  if (props.projects.length === 1) {
    args.push('--selectProjects', props.projects[0]);
  } else if (props.projects.length > 1) {
    args.push('--selectProjects', ...props.projects);
  }

  options.forEach(option => {
    if (props[option] === true) {
      args.push(`--${option}`);
    }
  });

  if (!props.runInBand) {
    // see https://ivantanev.com/make-jest-faster
    if (ci) {
      args.push('--runInBand');
    } else if (props.watch) {
      args.push('--maxWorkers', '25%');
    } else {
      args.push('--maxWorkers', '50%');
    }
  }

  if (ci) {
    args.push('--ci');
    args.push('--silent');
    args.push('--json');
    args.push('--outputFile', (0, _path.join)(coverageFolder, 'jest-final.json'));
  }

  args.push('--coverage');
  args.push('--coverageDirectory', coverageFolder);
  args.push('--coverageReporters', 'json');
  args.push('--coverageThreshold', '\'{"global":{"statements":0,"branches":0,"functions":0,"lines":0}}\'');
  log.info('Run test');
  await (0, _exec.default)({
    cmd,
    args,
    cwd,
    log,
    withInteraction: props.watch,
    withDirectOutput: true
  });
};

var _default = jest;
exports.default = _default;