"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _toolLib = require("@kettil/tool-lib");

var _chalk = require("chalk");

var _licenseCompatibilities = _interopRequireDefault(require("../../../configs/licenseCompatibilities"));

var _licensePackages = _interopRequireDefault(require("../../../configs/licensePackages"));

var _licenseDisabledError = _interopRequireDefault(require("../../errors/licenseDisabledError"));

var _licenseIncompatibleError = _interopRequireDefault(require("../../errors/licenseIncompatibleError"));

var _getPackageInfo = _interopRequireDefault(require("./helpers/getPackageInfo"));

var _getPackagePaths = _interopRequireDefault(require("./helpers/getPackagePaths"));

var _isLicenseCompatible = _interopRequireDefault(require("./helpers/isLicenseCompatible"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const licensecheck = async (argv, ignorePackages = []) => {
  const {
    cwd,
    log
  } = argv;
  const projectInfo = await (0, _getPackageInfo.default)(argv, {
    packagePath: cwd,
    ignorePackages: [],
    licensePackages: {}
  });

  if (!projectInfo) {
    throw new Error('Project package data was not found');
  }

  const projectLicense = projectInfo.license;
  const supportedLicenses = Object.keys(_licenseCompatibilities.default).sort();
  const compatibleLicences = _licenseCompatibilities.default[projectLicense];

  if (!(0, _toolLib.isArray)(compatibleLicences)) {
    throw new _licenseDisabledError.default('The project license has no compatibility group', `License verification is disabled (${projectLicense} != ${supportedLicenses.join('|')})`);
  }

  log.info('Get the paths of the packages');
  const packagePaths = await (0, _getPackagePaths.default)(cwd);
  log.info('Read the license data');
  const packageInfos = await Promise.all(packagePaths.map(packagePath => (0, _getPackageInfo.default)(argv, {
    packagePath,
    ignorePackages,
    licensePackages: _licensePackages.default
  })));
  log.info('Validation of the license data');
  const licenseCompatibleProps = {
    compatibleLicences: compatibleLicences.map(v => v.toUpperCase()),
    projectLicense
  };
  const incompatibleLicenses = packageInfos.filter(v => v !== undefined).filter(packageInfo => !(0, _isLicenseCompatible.default)({ ...licenseCompatibleProps,
    packageInfo
  })).map(({
    name,
    license,
    version,
    path
  }, index) => [`${index + 1}`, name, license, version, path]);

  if (incompatibleLicenses.length > 0) {
    incompatibleLicenses.unshift([(0, _chalk.red)('#'), (0, _chalk.red)('Name'), (0, _chalk.red)('License'), (0, _chalk.red)('Version'), (0, _chalk.red)('Path')]);
    throw new _licenseIncompatibleError.default('Incompatible licenses found', incompatibleLicenses);
  }
};

var _default = licensecheck;
exports.default = _default;