"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _helper = require("../helper");

const defaultBorder = {
  t: '─',
  tl: '┌',
  tb: '┬',
  tr: '┐',
  l: '│',
  lr: '├',
  c: '┼',
  ch: '─',
  cv: '│',
  r: '│',
  rl: '┤',
  b: '─',
  bl: '└',
  bt: '┴',
  br: '┘'
};

const getMaxColumnLengths = (maxLengths, row) => {
  if (maxLengths.length > 0 && maxLengths.length !== row.length) {
    throw new Error('The table rows are of different lengths');
  }

  return row.map(value => (0, _helper.cleanCliValue)(value).length).map((value, index) => typeof maxLengths[index] === 'number' ? Math.max(maxLengths[index], value) : value);
};

const cellFill = (cell, length) => cell + ' '.repeat(length - (0, _helper.cleanCliValue)(cell).length);

const tableBorder = (columnLengths, line, first, cross, last) => first + line + columnLengths.map(l => line.repeat(l)).join(line + cross + line) + line + last;

const tableRow = (columnLengths, row, separator, first, last) => `${first} ${columnLengths.map((length, i) => cellFill(row[i], length)).join(` ${separator} `)} ${last}`;

const table = (rows, border = defaultBorder) => {
  const {
    b,
    bl,
    br,
    bt,
    c,
    ch,
    cv,
    l,
    lr,
    r,
    rl,
    t,
    tb,
    tl,
    tr
  } = border;
  const columnLengths = rows.reduce(getMaxColumnLengths, []);
  const separator = tableBorder(columnLengths, ch, lr, c, rl);
  return [tableBorder(columnLengths, t, tl, tb, tr), rows.map(row => tableRow(columnLengths, row, cv, l, r)).join(`\n${separator}\n`), tableBorder(columnLengths, b, bl, bt, br)].join('\n');
};

var _default = table;
exports.default = _default;