"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = require("path");

var _add = _interopRequireDefault(require("../actions/git/add"));

var _commit = _interopRequireDefault(require("../actions/git/commit"));

var _init = _interopRequireDefault(require("../actions/git/init"));

var _file = _interopRequireDefault(require("../actions/node/file"));

var _folder = _interopRequireDefault(require("../actions/node/folder"));

var _template = _interopRequireDefault(require("../actions/node/template"));

var _init2 = _interopRequireDefault(require("../actions/npm/init"));

var _install = _interopRequireDefault(require("../actions/npm/install"));

var _packageLoad = _interopRequireDefault(require("../actions/npm/packageLoad"));

var _packageUpdate = _interopRequireDefault(require("../actions/npm/packageUpdate"));

var _spinner = require("../cli/spinner");

var _access = _interopRequireDefault(require("../cmd/access"));

var _exec = _interopRequireDefault(require("../cmd/exec"));

var _getInitSettings = _interopRequireDefault(require("./helpers/getInitSettings"));

var _getInitTemplateVariables = _interopRequireDefault(require("./helpers/getInitTemplateVariables"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const initTask = async (argv, props) => {
  const hasGitFolder = await (0, _access.default)((0, _path.join)(argv.cwd, '.git'));
  const hasPackage = await (0, _access.default)((0, _path.join)(argv.cwd, 'package.json'));
  const settings = (0, _getInitSettings.default)(props);

  if (hasPackage) {
    throw new Error('The project is already initialized');
  } // npm init


  await (0, _spinner.spinnerAction)((0, _init2.default)(argv, {
    settings: settings.packageInit
  }), 'Create the package.json');
  const packageName = await (0, _packageLoad.default)(argv, {
    key: 'name'
  });

  if (typeof packageName !== 'string') {
    throw new TypeError('Package name could not be read');
  }

  if (props.cli) {
    settings.packageBin[packageName] = 'build/bin/index.js';
  } // git init


  await (0, _spinner.spinnerAction)((0, _init.default)(argv), 'Create the git repository'); // create folders and files

  await (0, _spinner.spinnerAction)(Promise.all(settings.folders.map(folder => (0, _folder.default)(argv, {
    folder
  }))), 'Create the project folders');
  await (0, _spinner.spinnerAction)(Promise.all(settings.files.map(file => (0, _file.default)(argv, {
    file
  }))), 'Create the project files'); // create template files

  const templateVariables = (0, _getInitTemplateVariables.default)(settings);
  await (0, _spinner.spinnerAction)(Promise.all(settings.templates.map(([source, target]) => (0, _template.default)(argv, {
    source,
    target,
    variables: templateVariables
  }))), 'Create template files'); // npm install

  await (0, _spinner.spinnerAction)((0, _install.default)(argv, {
    packages: settings.libraryProduction,
    mode: 'prod'
  }), 'Install prod dependencies');
  await (0, _spinner.spinnerAction)((0, _install.default)(argv, {
    packages: settings.libraryDevelopment,
    mode: 'dev'
  }), 'Install dev dependencies'); // update package.json with settings

  await (0, _spinner.spinnerAction)((0, _packageUpdate.default)(argv, {
    settings: { ...settings.packageUpdate,
      bin: settings.packageBin,
      scripts: settings.packageScripts,
      peerDependencies: settings.packagePeerDependencies
    }
  }), 'Update the package.json'); // install package.json "prepare" command

  if (typeof settings.packageScripts.prepare === 'string') {
    await (0, _spinner.spinnerAction)((0, _exec.default)({
      cmd: 'npm',
      args: ['run', 'prepare'],
      cwd: argv.cwd,
      log: argv.log
    }), 'Enable git hooks handling');
  }

  if (!props.noCommit && !hasGitFolder) {
    // git add
    await (0, _spinner.spinnerAction)((0, _add.default)(argv, {
      files: ['.']
    }), 'Add files to repository'); // git commit

    await (0, _spinner.spinnerAction)((0, _commit.default)(argv, {
      msg: 'feat: 🐣'
    }), 'Create the initial commit');
  }
};

var _default = initTask;
exports.default = _default;