"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _toolLib = require("@kettil/tool-lib");

var _chalk = require("chalk");

var _licensecheck = _interopRequireDefault(require("../actions/tools/licensecheck"));

var _config = _interopRequireDefault(require("../cli/config"));

var _spinner = require("../cli/spinner");

var _table = _interopRequireDefault(require("../cli/table"));

var _licenseDisabledError = _interopRequireDefault(require("../errors/licenseDisabledError"));

var _licenseIncompatibleError = _interopRequireDefault(require("../errors/licenseIncompatibleError"));

var _helper = require("../helper");

var _taskHook = _interopRequireDefault(require("./helpers/taskHook"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const notice = `the check is only a suggestion and is ${(0, _chalk.underline)('not')} legal advice`;

const licenseTask = async argv => {
  try {
    const configIgnorePackages = await (0, _config.default)(argv.cwd, 'license.ignore.packages');
    const ignorePackages = (0, _toolLib.isArray)(configIgnorePackages) ? configIgnorePackages.filter(v => typeof v === 'string') : [];
    await (0, _taskHook.default)(argv, {
      task: 'license',
      type: 'pre'
    });
    await (0, _spinner.spinnerAction)((0, _licensecheck.default)(argv, ignorePackages), `License verification (${notice})`);
    await (0, _taskHook.default)(argv, {
      task: 'license',
      type: 'post'
    });
  } catch (error) {
    if (error instanceof _licenseDisabledError.default) {
      return;
    }

    if (error instanceof _licenseIncompatibleError.default) {
      argv.log.log(' ');
      argv.log.log((0, _table.default)(error.list));
      argv.log.log(' ');
      (0, _helper.exit)();
    }

    throw error;
  }
};

var _default = licenseTask;
exports.default = _default;