"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _toolLib = require("@kettil/tool-lib");

var _add = _interopRequireDefault(require("../../actions/git/add"));

var _ls = _interopRequireDefault(require("../../actions/git/ls"));

var _staged = _interopRequireDefault(require("../../actions/git/staged"));

var _eslint = require("../../actions/tools/eslint");

var _prettier = require("../../actions/tools/prettier");

var _existFiles = _interopRequireDefault(require("../../cmd/existFiles"));

var _analyseTask = _interopRequireDefault(require("../analyseTask"));

var _testTask = _interopRequireDefault(require("../testTask"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const testEslint = new RegExp(`(${_eslint.eslintExtensionAll.replace(/,/g, '|')})$`);
const testPrettier = new RegExp(`(${_prettier.prettierExtensionAll.replace(/,/g, '|')})$`);

const gitCommitTask = async argv => {
  const stagedFiles = await (0, _staged.default)(argv, {});

  if (stagedFiles.length === 0) {
    return;
  }

  const files = await (0, _existFiles.default)(stagedFiles, argv.cwd);
  const eslintFiles = files.filter(file => testEslint.test(file));
  const prettierFiles = files.filter(file => testPrettier.test(file));
  const mergedFiles = (0, _toolLib.uniqueArray)([...prettierFiles, ...eslintFiles]);
  const unstagedFiles = await (0, _ls.default)(argv, {
    mode: 'all'
  });
  const intersectFiles = mergedFiles.filter(file => unstagedFiles.includes(file));

  if (intersectFiles.length > 0) {
    throw new Error(`The following files were changed after adding:\n${intersectFiles.map(file => `       ▸ ${file}\n`).join('')}`);
  }

  await (0, _analyseTask.default)({ ...argv,
    ci: false
  }, {
    eslintFiles,
    prettierFiles
  });
  await (0, _add.default)(argv, {
    files
  });
  await (0, _testTask.default)({ ...argv,
    ci: true
  }, {});
};

var _default = gitCommitTask;
exports.default = _default;