"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _toolLib = require("@kettil/tool-lib");

var _coverage = _interopRequireDefault(require("../actions/tools/coverage"));

var _jest = _interopRequireDefault(require("../actions/tools/jest"));

var _config = _interopRequireDefault(require("../cli/config"));

var _spinner = require("../cli/spinner");

var _getTestProjects = _interopRequireDefault(require("./helpers/getTestProjects"));

var _taskHook = _interopRequireDefault(require("./helpers/taskHook"));

var _testHook = _interopRequireDefault(require("./helpers/testHook"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const transformThreshold = (key, value) => {
  if ((0, _toolLib.isArray)(value) && value.length === 2 && typeof value[0] === 'number' && typeof value[1] === 'number') {
    return [key, value];
  }

  if (typeof value === 'number') {
    return [key, value];
  }

  return [key, undefined];
};

const testTask = async (argv, props) => {
  const configThreshold = await (0, _config.default)(argv.cwd, 'test.coverage.threshold');
  const coverageThreshold = (0, _toolLib.isObject)(configThreshold) ? (0, _toolLib.objectMap)(configThreshold, transformThreshold) : undefined;
  await (0, _taskHook.default)(argv, {
    task: 'test',
    type: 'pre'
  });
  const projects = await (0, _getTestProjects.default)(argv, props.projects);

  if (props.watch) {
    await projects.reduce((promise, project) => promise.then(() => (0, _testHook.default)(argv, {
      project,
      type: 'pre'
    })), Promise.resolve());
    await (0, _jest.default)(argv, { ...props,
      projects
    });
    await projects.reduce((promise, project) => promise.then(() => (0, _testHook.default)(argv, {
      project,
      type: 'post'
    })), Promise.resolve());
  } else {
    await projects.reduce((promise, project) => promise.then(async () => {
      await (0, _testHook.default)(argv, {
        project,
        type: 'pre'
      });
      await (0, _spinner.spinnerAction)((0, _jest.default)(argv, { ...props,
        projects: [project]
      }), `Test: ${project}`);
      await (0, _testHook.default)(argv, {
        project,
        type: 'post'
      });
    }), Promise.resolve());
    await (0, _coverage.default)(argv, {
      projects,
      watermarks: coverageThreshold
    });
  }

  await (0, _taskHook.default)(argv, {
    task: 'test',
    type: 'post'
  });
};

var _default = testTask;
exports.default = _default;